@@ -1,7 +1,7 @@
 use std::any::Any;
 
 pub trait Response {
-    fn as_any(&self) -> &dyn Any;
+    fn as_any(&mut self) -> &mut dyn Any;
 
     fn get_response_name(&self) -> String;
 }
\ No newline at end of file
