@@ -1,10 +1,17 @@
 #[cfg(test)]
 pub mod some_command_for_tests {
     use std::any::Any;
+    use std::fmt::{Debug, Formatter};
     use crate::dddk::command::command::Command;
 
     pub struct ACommand {}
 
+    impl Debug for ACommand {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "ACommand")
+        }
+    }
+
     impl Command for ACommand {
         fn as_any(&self) -> &dyn Any {
             self
@@ -17,6 +24,12 @@ pub mod some_command_for_tests {
 
     pub struct AnotherCommand {}
 
+    impl Debug for AnotherCommand {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "AnotherCommand")
+        }
+    }
+
     impl Command for AnotherCommand {
         fn as_any(&self) -> &dyn Any {
             self
