@@ -1,6 +1,7 @@
 #[cfg(test)]
 pub mod some_event_for_test {
     use std::any::Any;
+    use std::fmt::{Debug, Formatter};
     use crate::dddk::event::event::Event;
 
     pub struct AnEvent {
@@ -13,6 +14,12 @@ pub mod some_event_for_test {
         }
     }
 
+    impl Debug for AnEvent {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "AnEvent")
+        }
+    }
+
     impl Event for AnEvent {
         fn as_any(&self) -> &dyn Any {
             self
@@ -35,6 +42,12 @@ pub mod some_event_for_test {
         }
     }
 
+    impl Debug for AnotherEvent {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "AnEvent")
+        }
+    }
+
     impl Event for AnotherEvent {
         fn as_any(&self) -> &dyn Any {
             self
