@@ -1,6 +1,7 @@
 #[cfg(test)]
 pub mod some_query_for_test {
     use std::any::Any;
+    use std::fmt::{Debug, Formatter};
     use crate::dddk::query::query::Query;
 
     pub struct AQuery {}
@@ -15,8 +16,20 @@ pub mod some_query_for_test {
         }
     }
 
+    impl Debug for AQuery {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "AQuery")
+        }
+    }
+
     pub struct AnotherQuery {}
 
+    impl Debug for AnotherQuery {
+        fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+            write!(f, "AnotherQuery")
+        }
+    }
+
     impl Query for AnotherQuery {
         fn as_any(&self) -> &dyn Any {
             self
