@@ -6,7 +6,7 @@ pub mod some_response_for_test {
     pub struct AResponse {}
 
     impl Response for AResponse {
-        fn as_any(&self) -> &dyn Any {
+        fn as_any(&mut self) -> &mut dyn Any {
             self
         }
 
@@ -18,7 +18,7 @@ pub mod some_response_for_test {
     pub struct AnotherResponse {}
 
     impl Response for AnotherResponse {
-        fn as_any(&self) -> &dyn Any {
+        fn as_any(&mut self) -> &mut dyn Any {
             self
         }
 
